@@ -11,10 +11,15 @@ public:
     explicit NymeaNetworkManagerDBusService(QDBusConnection::BusType busType, QObject *parent = nullptr);
 
 public slots:
-    Q_SCRIPTABLE void enableBluetoothServer();
+    Q_SCRIPTABLE void enableBluetoothServer(); // Deprecated
+
+    Q_SCRIPTABLE void startBluetoothServer();
+    Q_SCRIPTABLE void stopBluetoothServer();
 
 signals:
     void enableBluetoothServerCalled();
+    void startBluetoothServerRequested();
+    void stopBluetoothServerRequested();
 
 private:
     QDBusConnection m_connection;
